### R code from vignette source 'Vignette.Rnw'
### Encoding: UTF-8

###################################################
### code chunk number 1: Vignette.Rnw:6-7
###################################################
library(CellCODE)


###################################################
### code chunk number 2: Vignette.Rnw:12-18
###################################################
data("GSE20300")
data("GSE20300.grp")
data("cellCounts")
data("Garvan")
data("IRIS")
data("DMAP")


###################################################
### code chunk number 3: Vignette.Rnw:21-33
###################################################
dmapTag=tagData(DMAP[, c("MEGA2", "ERY5", "MONO2", "GRAN3", 
                         "DENDA1", "TCELLA7",   
                         "NKA2",   "BCELLA2")], 0.7, max=15,
                ref=GSE20300, ref.mean=F)
colnames(dmapTag)[1:2]=c("Megakaryocyte", "Erythrocyte")
irisTag=tagData(IRIS[,c("Neutrophil-Resting","CD4Tcell-N0", 
                        "Monocyte-Day0", "Bcell-naïve",
                        "NKcell-control" )],2, max=15, 
                ref=GSE20300, ref.mean=F);
colnames(irisTag)=c("Neutrophil","Tcell", "Monocyte", 
                    "Bcell", "NKcell" )
tmpTag=combineTags(irisTag, dmapTag[,1:2])


###################################################
### code chunk number 4: Vignette.Rnw:38-40
###################################################
SPVs=getAllSPVs(GSE20300, grp=GSE20300.grp, tmpTag, method="mixed",
               plot=T, mix.par=0.3)


###################################################
### code chunk number 5: Vignette.Rnw:47-57
###################################################
par(mfrow=c(1,3), cex=1.1)
for ( i in 1:3){
  plot( cellCounts[,i], SPVs[,i], pch=19,
        ylab=paste(colnames(SPVs)[i], "estimate"),
        xlab="counts")
  title(paste(colnames(cellCounts)[i],"\nr=",
              format.pval(cor(SPVs[,i], 
                              cellCounts[,i], method="p"), 
                          digits=2)))
}


###################################################
### code chunk number 6: Vignette.Rnw:62-64
###################################################
IRISsub=IRIS[,c("Neutrophil-Resting", "CD4Tcell-N0", 
                "Monocyte-Day0", "DendriticCell-Control", "Bcell-naïve")]


###################################################
### code chunk number 7: Vignette.Rnw:67-69
###################################################
mm=apply(IRISsub,1,max)
IRISsub=IRISsub[mm>4,]


###################################################
### code chunk number 8: Vignette.Rnw:74-76
###################################################
set.seed(123)
simRes=simulateMixture(pureData=2**IRISsub, targetVals=t(cellCounts), cellpop=2)


###################################################
### code chunk number 9: Vignette.Rnw:80-84
###################################################
simData=simRes$data
simData=randomizeExp(simRes$data, sd=0.22)
simData=log2(simData)
print(mean(varExplained(simData, model.matrix(~1+cellCounts))))


###################################################
### code chunk number 10: Vignette.Rnw:88-89
###################################################
grp=as.factor(rep(c(1,2), each=12))


###################################################
### code chunk number 11: Vignette.Rnw:93-94
###################################################
Gt=tagData(Garvan, cutoff=2.5, max=15, ref=simData)


###################################################
### code chunk number 12: Vignette.Rnw:97-98
###################################################
SPVs=getAllSPVs((simData),grp=grp, dataTag=Gt[,], plot=T, method="mixed")


###################################################
### code chunk number 13: Vignette.Rnw:101-102
###################################################
par(mfrow=c(1,5));for (i in 1:5){plot(SPVs[,i], cellCounts[,i], col=grp)}


###################################################
### code chunk number 14: Vignette.Rnw:106-116
###################################################
ttraw=lm.coef(simData,model.matrix(~1+grp))
ttcount=lm.coef(simData,model.matrix(~1+grp+cellCounts))
ttcellcode=lm.coef(simData,model.matrix(~1+grp+SPVs))
deRes=c(numAtFDR(simRes$vals!=0,abs(ttraw$tstat[,2]), at=0.1),
numAtFDR(simRes$vals!=0,abs(ttcount$tstat[,2]), at=0.1),
nn<-numAtFDR(simRes$vals!=0,abs(ttcellcode$tstat[,2]), at=0.1))
deRes=cbind(deRes)
rownames(deRes)=c("raw", "count", "CellCODE")
message("number of genes at FDR=0.1")
print(deRes)


###################################################
### code chunk number 15: Vignette.Rnw:120-130
###################################################
cutoff=sort(abs(ttcellcode$tstat[,2]),T)[nn]
iiDF=which(abs(ttcellcode$tstat[,2])>=cutoff&simRes$vals!=0)
resf=cellPopF(simData[iiDF,], grp, SPVs)
rest=cellPopT(simData[iiDF,], grp, SPVs)
resc=cellPopC(simData[iiDF,], grp, SPVs)
fracs=c(colSums(isRowmax(resc))[2], colSums(isRowmax(rest))[2],colSums(isRowmax(resf))[2])/length(iiDF)
fracs=cbind(fracs)
rownames(fracs)=c("cor Test", "T Test", "F Test")
message("fraction correctly assigned")
print(fracs)


